/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_FileModeBinding_h__
#define mozilla_dom_FileModeBinding_h__

#include "js/RootingAPI.h"
#include "jspubtd.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingDeclarations.h"
#include "mozilla/dom/Nullable.h"

namespace mozilla {
namespace dom {

class NativePropertyHooks;
class ProtoAndIfaceArray;

} // namespace dom
} // namespace mozilla

namespace mozilla {
namespace dom {


MOZ_BEGIN_ENUM_CLASS(FileMode, uint32_t)
  Readonly,
  Readwrite
MOZ_END_ENUM_CLASS(FileMode)

namespace FileModeValues {
extern const EnumEntry strings[3];
} // namespace FileModeValues


} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_FileModeBinding_h__
